@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Modules/ProhibitAutomaticExportation.pm $
-#     $Date: 2010-06-22 16:14:07 -0400 (Tue, 22 Jun 2010) $
-#   $Author: clonezone $
-# $Revision: 3843 $
-##############################################################################
-
 package Perl::Critic::Policy::Modules::ProhibitAutomaticExportation;
 
 use 5.006001;
@@ -16,7 +9,7 @@ use Perl::Critic::Utils qw{ :severities };
 use List::MoreUtils qw(any);
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.108';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -129,7 +122,7 @@ and let the caller choose exactly which symbols to export.
 
     package Foo;
 
-    use base qw(Exporter);
+    use Exporter 'import';
     our @EXPORT      = qw(foo $bar @baz);                  # not ok
     our @EXPORT_OK   = qw(foo $bar @baz);                  # ok
     our %EXPORT_TAGS = ( all => [ qw(foo $bar @baz) ] );   # ok
@@ -147,7 +140,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2010 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
