@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/PolicyParameter/Behavior/Integer.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::PolicyParameter::Behavior::Integer;
 
 use 5.006001;
@@ -15,7 +8,7 @@ use Perl::Critic::Utils qw{ :characters };
 
 use base qw{ Perl::Critic::PolicyParameter::Behavior };
 
-our $VERSION = '1.088';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -33,7 +26,7 @@ sub initialize_parameter {
             # Normally bad thing, obscuring a variable in a outer scope
             # with a variable with the same name is being done here in
             # order to remain consistent with the parser function interface.
-            my ($policy, $parameter, $config_string) = @_;
+            my ($policy, $parameter, $config_string) = @_;  ## no critic(Variables::ProhibitReusedNames)
 
             my $value_string = $parameter->get_default_string();
 
@@ -137,14 +130,21 @@ Perl::Critic::PolicyParameter::Behavior::Integer - Actions appropriate for an in
 =head1 DESCRIPTION
 
 Provides a standard set of functionality for an integer
-L<Perl::Critic::PolicyParameter> so that the developer of a policy
-does not have to provide it her/himself.
+L<Perl::Critic::PolicyParameter|Perl::Critic::PolicyParameter> so that
+the developer of a policy does not have to provide it her/himself.
 
 The parser provided by this behavior allows underscores ("_") in input
 values as in a Perl numeric literal.
 
 NOTE: Do not instantiate this class.  Use the singleton instance held
-onto by L<Perl::Critic::PolicyParameter>.
+onto by
+L<Perl::Critic::PolicyParameter|Perl::Critic::PolicyParameter>.
+
+
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class.  Its interface is subject
+to change without notice.
 
 
 =head1 METHODS
@@ -164,12 +164,15 @@ This behavior looks for two configuration items:
 
 Optional.  The minimum acceptable value.  Inclusive.
 
+
 =item integer_maximum
 
 Optional.  The maximum acceptable value.  Inclusive.
 
+
 =back
 
+
 =item C<generate_parameter_description( $parameter )>
 
 Create a description of the parameter, based upon the description on
@@ -178,6 +181,7 @@ behavior.
 
 In this case, this means including the minimum and maximum values.
 
+
 =back
 
 
@@ -185,9 +189,10 @@ In this case, this means including the minimum and maximum values.
 
 Elliot Shank <perl@galumph.com>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2011 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
